@@ -2,9 +2,9 @@
 #' @export
 generics::tidy
 
-tidy_data_frame <- function(x, 
-                            conf.int = FALSE,
-                            conf.level = .95,
+tidy_data_frame <- function(x,
+                            conf.int = TRUE,
+                            conf.level = NULL,
                             ...) {
   vec_cols <- c(
     "coefficients",
@@ -16,9 +16,20 @@ tidy_data_frame <- function(x,
     "df"
   )
 
+  if(!conf.int){
+    vec_cols <- c(
+      "coefficients",
+      "std.error",
+      "statistic",
+      "p.value",
+      "df"
+    )
+  }
+
   tidy_mat <- do.call("cbind", lapply(x[vec_cols], as.vector))
   vec_cols[vec_cols == "coefficients"] <- "estimate"
   colnames(tidy_mat) <- vec_cols
+
   return_frame <- data.frame(
     term = x[["term"]],
     tidy_mat,
@@ -28,18 +39,13 @@ tidy_data_frame <- function(x,
 
   rownames(return_frame) <- NULL
 
-  # re-calculate CIs if explicitly requested and alpha level has changed
-  # x$alpha[1] because lm_robust duplicates alpha with multiple linear_hypotheses
-  flag <- conf.int || (utils::hasName(x, 'alpha') && (1 - x$alpha[1] != conf.level))
-  if (flag) {
-      ci <- stats::confint(x, level = conf.level, ...)
-      if (all(row.names(ci) == return_frame$term))  {
-          return_frame$conf.low <- ci[, 1]
-          return_frame$conf.high <- ci[, 2]
-      }
+  if(!is.null(conf.level) && conf.int){
+    ci <- stats::confint(x, level = conf.level, ...)
+    if (all(row.names(ci) == return_frame$term))  {
+      return_frame$conf.low <- ci[, 1]
+      return_frame$conf.high <- ci[, 2]
+    }
   }
-
-
   return(return_frame)
 }
 
@@ -63,7 +69,7 @@ warn_singularities <- function(x) {
 #'
 #' @param x An object returned by one of the estimators
 #' @param conf.int  Logical indicating whether or not to include a
-#'   confidence interval in the tidied output. Defaults to ‘FALSE’.
+#'   confidence interval in the tidied output. Defaults to ‘TRUE’.
 #' @param conf.level  The confidence level to use for the confidence
 #'   interval if ‘conf.int = TRUE’. Must be strictly greater than 0 and less
 #'   than 1. Defaults to 0.95, which corresponds to a 95 percent confidence
@@ -75,8 +81,8 @@ warn_singularities <- function(x) {
 #' @seealso [generics::tidy()], [estimatr::lm_robust()], [estimatr::iv_robust()],  [estimatr::difference_in_means()], [estimatr::horvitz_thompson()]
 #' @md
 tidy.lm_robust <- function(x,
-                           conf.int = FALSE,
-                           conf.level = .95,
+                           conf.int = TRUE,
+                           conf.level = NULL,
                            ...) {
   warn_singularities(x)
   tidy_data_frame(x, conf.int = conf.int, conf.level = conf.level, ...)
@@ -87,7 +93,7 @@ tidy.lm_robust <- function(x,
 #'
 #' @export
 #' @family estimatr tidiers
-tidy.iv_robust <- function(x, conf.int = FALSE, conf.level = .95, ...) {
+tidy.iv_robust <- function(x, conf.int = TRUE, conf.level = NULL, ...) {
   warn_singularities(x)
   tidy_data_frame(x, conf.int = conf.int, conf.level = conf.level, ...)
 }
@@ -111,8 +117,12 @@ tidy.horvitz_thompson <- tidy_data_frame
 #'
 #' @export
 #' @family estimatr tidiers
-tidy.lh_robust <- function(x, ...) {
-  rbind(tidy(x$lm_robust, ...), tidy(x$lh, ...))
+tidy.lh_robust <- function(x,
+                           conf.int = TRUE,
+                           conf.level = NULL,
+                           ...) {
+  rbind(tidy(x$lm_robust, conf.int = conf.int, conf.level = conf.level, ...),
+        tidy(x$lh, conf.int = conf.int, conf.level = conf.level, ...))
 }
 
 #' @rdname estimatr_tidiers
@@ -120,8 +130,11 @@ tidy.lh_robust <- function(x, ...) {
 #'
 #' @export
 #' @family estimatr tidiers
-tidy.lh <- function(x, ...) {
-  tidy_data_frame(simplify_lh_outcome(x), ...)
+tidy.lh <- function(x,
+                    conf.int = TRUE,
+                    conf.level = NULL,
+                    ...) {
+  tidy_data_frame(simplify_lh_outcome(x), conf.int = conf.int, conf.level = conf.level, ...)
 }
 
 # Simplifies the `lh` outcome column for tidy.lh and print.lh
